package com.htfp.weather.griddata.utils;

import org.apache.commons.lang3.StringUtils;
import ucar.nc2.Attribute;
import ucar.nc2.NetcdfFile;
import ucar.nc2.Variable;

import java.io.IOException;
import java.time.ZonedDateTime;

/**
 * @Author : shiyi
 * @Date : 2024/3/4 10:19
 * @Description : Gfs数据工具类
 */
public class GfsUtils {
    /**
     * 从cdf文件中获取起报时间，并转换为时区字符串格式
     * @param ncFile
     * @return 时区字符串："yyyy-MM-dd'T'HH:mmxxx"，例如"2023-09-05T08:00+08:00"
     * @throws IOException
     */
    public static String getRefTime(NetcdfFile ncFile) throws IOException {
        Variable time = ncFile.findVariable("reftime");
        if ( time!= null) {
            int hour = (int) time.read().getDouble(0);
            Attribute units = time.findAttribute("units");
            if (units != null) {
                String stringValue = units.getStringValue();
                if (StringUtils.isNotBlank(stringValue)) {
                    // "Hour since 2023-09-05T00:00:00Z"  // utc时间
                    ZonedDateTime zonedDateTime = ZonedDateTime.parse(stringValue.substring(11)).plusHours(hour);
                    return zonedDateTime.format(CoordinateUtils.DATE_TIME_FORMATTER);
                }
            }
        }
        return null;
    }
}
