package com.htfp.weather.utils;

import lombok.extern.slf4j.Slf4j;
import okhttp3.OkHttpClient;
import okhttp3.Request;
import okhttp3.Request.Builder;
import okhttp3.Response;
import okhttp3.ResponseBody;
import org.apache.commons.lang3.StringUtils;
import org.springframework.util.CollectionUtils;

import java.io.IOException;
import java.io.UnsupportedEncodingException;
import java.net.URLEncoder;
import java.util.Map;
import java.util.concurrent.TimeUnit;

/**
 * @Author : shiyi
 * @Date : 2024/1/23 16:19
 * @Description : HttpClient工具类
 */
@Slf4j
public class HttpClientUtils {
    private static final OkHttpClient OKHTTP_CLIENT = new OkHttpClient.Builder()
            .connectTimeout(30, TimeUnit.SECONDS)
            .readTimeout(60, TimeUnit.SECONDS)
            .writeTimeout(60, TimeUnit.SECONDS)
            .build();

    // public static <T> T sendGet(String url, Map<String, String> params, Class<T> responseClass) {
    //     MultiValueMap<String, String> queryParams = new LinkedMultiValueMap<>();
    //     if (params != null) {
    //         params.forEach(queryParams::add);
    //     }
    //     Mono<T> mono = WebClient.create(url).method(HttpMethod.GET)
    //             .uri(uriBuilder -> uriBuilder
    //                     .queryParams(queryParams)
    //                     .build()).retrieve().bodyToMono(responseClass);
    //     T responseBody;
    //     try {
    //         responseBody = mono.block();
    //     } catch (WebClientResponseException e) {
    //         log.error("Get 请求错误, {}", e.getMessage());
    //         return null;
    //     }
    //     return responseBody;
    // }
    public static <T> T sendGet(String url, Map<String, String> params, Class<T> responseClass) throws Exception {
        String jsonStr = sendGet(url, params);
        return JSONUtils.json2pojo(jsonStr, responseClass);
    }
    public static String sendGet(String url, Map<String, String> params) throws IOException {
        StringBuilder stringBuilder = new StringBuilder();
        if (!CollectionUtils.isEmpty(params)) {
            params.keySet().forEach(res -> {
                if (StringUtils.isNotBlank(stringBuilder)) {
                    stringBuilder.append("&");
                } else {
                    stringBuilder.append("?");
                }
                try {
                    stringBuilder.append(String.format("%s=%s", res, URLEncoder.encode(params.get(res), "UTF-8")));
                } catch (UnsupportedEncodingException e) {
                    throw new RuntimeException(e);
                }
            });
        }
        Request request = new Builder()
                .url(url + stringBuilder)
                .build();

        try (Response response = OKHTTP_CLIENT.newCall(request).execute()) {
            if (!response.isSuccessful()) {
                throw new IOException("okhttp Unexpected code " + response);
            }
            ResponseBody body = response.body();
            if (body != null) {
                return body.string();
            } else {
                return null;
            }
        }
    }

}
