package com.htfp.weather.web.controller;

import com.htfp.weather.web.pojo.hefeng.HeFengWarningResponse;
import com.htfp.weather.web.pojo.request.Position2D;
import com.htfp.weather.web.pojo.response.NowWeatherStatus;
import com.htfp.weather.web.pojo.response.Result;
import com.htfp.weather.web.pojo.response.SurfaceWeatherWarning;
import com.htfp.weather.web.pojo.response.TimeSeriesDataset;
import com.htfp.weather.web.service.surfaceapi.CaiYunServiceImpl;
import com.htfp.weather.web.service.surfaceapi.HeFengServiceImpl;
import com.htfp.weather.web.service.IDataService;
import com.htfp.weather.web.service.surfaceapi.ISurfaceDataService;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;
import java.util.List;

/**
 * @Author : shiyi
 * @Date : 2024/1/24 16:07
 * @Description : 地面天气状态
 */
@CrossOrigin
@RestController
@RequestMapping("/htfp/weather/surface/")
public class SurfaceWeatherController {
    @Resource(name = "tablestore-gfs")
    IDataService dataService;
    @Resource(name = "caiyun")
    ISurfaceDataService surfaceDataService;

    @PostMapping("/now")
    public Result queryNowWeather(@Validated @RequestBody Position2D position2D) throws Exception {
        double lat = position2D.getLatitude();
        double lon = position2D.getLongitude();
        NowWeatherStatus nowWeatherStatus = surfaceDataService.getNowSurfaceWeatherStatus(lat, lon);
        return Result.success(nowWeatherStatus);
    }

    @PostMapping("/forecast")
    public Result querySurfaceForecastWeather(@Validated @RequestBody Position2D position2D) throws Exception {
        double lat = position2D.getLatitude();
        double lon = position2D.getLongitude();
        TimeSeriesDataset forecastSeries = surfaceDataService.getForecastSeries(lat, lon);
        return Result.success(forecastSeries);
    }

    @PostMapping ("/warning")
    public Result warning(@Validated @RequestBody Position2D position2D) throws Exception {
        double lat = position2D.getLatitude();
        double lon = position2D.getLongitude();
        List<SurfaceWeatherWarning> warning = surfaceDataService.getSurfaceWarning(lat, lon);
        return Result.success(warning);
    }

}
